﻿using System;

using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;

namespace Platform.Modules.Abstract
{
    public interface IModuleHost
    {
        /// <summary>
        /// Gets the instance id
        /// </summary>
        string Id { get; }

        /// <summary>
        /// Gets the host name
        /// </summary>
        string Name { get; }

        /// <summary>
        /// Gets the instance name
        /// </summary>
        string Instance { get; }

        /// <summary>
        /// Gets the folder of this host
        /// </summary>
        string Folder { get; }

        /// <summary>
        /// Gets the configuration
        /// </summary>
        IConfigurationRoot Configuration { get; }

        /// <summary>
        /// Gets the provider
        /// </summary>
        IServiceProvider Provider { get; }

        /// <summary>
        /// Gets the services
        /// </summary>
        // IServiceCollection Services { get; }

        /// <summary>
        /// Signals host initialization complete
        /// </summary>
        // event EventHandler Initialized;

        /// <summary>
        /// Add a module
        /// </summary>
        /// <param name="module"></param>
        void AddModule(IModule module);

        /// <summary>
        /// Initialize all modules
        /// </summary>
        void Initialize();

        /// <summary>
        /// Start module host
        /// </summary>
        void Start();

        /// <summary>
        /// Stop module host
        /// </summary>
        void Stop();

        /// <summary>
        /// Restart module host
        /// </summary>
        void Restart();
    }
}
